==> aar_multi_chip-1.1.78-sources.jar: com/xdja/multichip/process/vhsm/net/NetVhsmProcessProvider.java <==
package com.xdja.multichip.process.vhsm.net;

import android.content.ContentProvider;
import android.content.ContentValues;
import android.database.Cursor;
import android.net.Uri;
import android.os.Bundle;
import android.text.TextUtils;

import com.xdja.multichip.param.ParamKeywords;

import java.util.ArrayList;

/**
 * @author zhangxiaolong@xdja.com <br/>
 * @date 2018/11/16 <br/>
 */
public class NetVhsmProcessProvider extends ContentProvider {
    @Override
    public boolean onCreate() {
        return false;
    }


    @Override
    public Cursor query(Uri uri, String[] projection, String selection, String[] selectionArgs, String sortOrder) {
        return null;
    }


    @Override
    public String getType(Uri uri) {
        return null;
    }


    @Override
    public Uri insert(Uri uri, ContentValues values) {
        return null;
    }

    @Override
    public int delete(Uri uri, String selection, String[] selectionArgs) {
        return 0;
    }

    @Override
    public int update(Uri uri, ContentValues values, String selection, String[] selectionArgs) {
        return 0;
    }


    @Override
    public Bundle call(String method, String arg, Bundle extras) {
        if (ParamKeywords.KEY_METHOD_GetJniApiBinder.equals(method)) {
            Bundle bundle = new Bundle();
            if (TextUtils.isEmpty(arg) || TextUtils.isEmpty(ParamKeywords.KEY_String_GetDefaultVhsm)) {
                ArrayList<Bundle> list = new ArrayList<>();

                Bundle defaultVhsm = NetVhsmJniApiHandle.getInstance().getNetVhsm(getContext());
                if (defaultVhsm != null) {
                    list.add(defaultVhsm);
                }
                bundle.putInt(ParamKeywords.KEY_int_ret, 0);
                bundle.putParcelableArrayList("result", list);
            }
            return bundle;
        }
        return super.call(method, arg, extras);
    }
}

==> aar_multi_chip-1.1.103.1-sources.jar: com/xdja/multichip/process/vhsm/net/NetVhsmProcessProvider.java <==
package com.xdja.multichip.process.vhsm.net;

import android.content.ContentProvider;
import android.content.ContentValues;
import android.database.Cursor;
import android.net.Uri;
import android.os.Bundle;
import android.text.TextUtils;

import com.xdja.multichip.param.ParamKeywords;

import java.util.ArrayList;

/**
 * @author zhangxiaolong@xdja.com <br/>
 * @date 2018/11/16 <br/>
 */
public class NetVhsmProcessProvider extends ContentProvider {
    @Override
    public boolean onCreate() {
        return false;
    }


    @Override
    public Cursor query(Uri uri, String[] projection, String selection, String[] selectionArgs, String sortOrder) {
        return null;
    }


    @Override
    public String getType(Uri uri) {
        return null;
    }


    @Override
    public Uri insert(Uri uri, ContentValues values) {
        return null;
    }

    @Override
    public int delete(Uri uri, String selection, String[] selectionArgs) {
        return 0;
    }

    @Override
    public int update(Uri uri, ContentValues values, String selection, String[] selectionArgs) {
        return 0;
    }


    @Override
    public Bundle call(String method, String arg, Bundle extras) {
        if (ParamKeywords.KEY_METHOD_GetJniApiBinder.equals(method)) {
            Bundle bundle = new Bundle();
            if (TextUtils.isEmpty(arg) || TextUtils.isEmpty(ParamKeywords.KEY_String_GetDefaultVhsm)) {
                ArrayList<Bundle> list = new ArrayList<>();

                Bundle defaultVhsm = NetVhsmJniApiHandle.getInstance().getNetVhsm(getContext());
                if (defaultVhsm != null) {
                    list.add(defaultVhsm);
                }
                bundle.putInt(ParamKeywords.KEY_int_ret, 0);
                bundle.putParcelableArrayList(ParamKeywords.KEY_Parcelable_JniApiParam, list);
            }
            return bundle;
        }
        return super.call(method, arg, extras);
    }
}
